@@ -4,7 +4,9 @@
 #' @import mlr3misc
 #' @import mlr3
 #' @import bbotk
+#' @import mlr3pipelines
 #' @importFrom R6 R6Class
+#' @importFrom utils combn head tail
 "_PACKAGE"
 
 .onLoad = function(libname, pkgname) {
@@ -15,3 +17,5 @@
     lg$set_threshold("warn")
   }
 } # nocov end
+
+leanify_package()
