@@ -1,5 +1,3 @@
-context("FSelectorDesignPoints")
-
 test_that("FSelectorDesignPoints", {
   design = data.table(
     x1 = c(TRUE, FALSE),
@@ -8,7 +6,7 @@ test_that("FSelectorDesignPoints", {
     x4 = c(FALSE, TRUE))
 
   z = test_fselector("design_points", design = design, batch_size = 10, term_evals = 10, real_evals = 2)
-  a = z$inst$archive$data()
+  a = z$inst$archive$data
   expect_equal(a[, 1:4], design)
 })
 
@@ -20,6 +18,6 @@ test_that("FSelectorDesignPoints works with multi-crit", {
     x4 = c(FALSE, TRUE))
 
   z = test_fselector_2D("design_points", design = design, batch_size = 1, term_evals = 10, real_evals = 2)
-  a = z$inst$archive$data()
+  a = z$inst$archive$data
   expect_equal(a[, 1:4], design)
 })
